package gmodel

import (
	"context"
	"errors"
	"gorm.io/gorm"
)

func (s *FsProductSizeModel) FindOne(ctx context.Context, id int64) (resp FsProductSize, err error) {
	err = s.db.WithContext(ctx).Model(&FsProductSize{}).Where("`id` = ? ", id).First(&resp).Error
	if err != nil && !errors.Is(err, gorm.ErrRecordNotFound) {
		return FsProductSize{}, err
	}
	return resp, nil
}
func (s *FsProductSizeModel) GetAllByIds(ctx context.Context, ids []int64, sort string) (resp []FsProductSize, err error) {
	if len(ids) == 0 {
		return
	}
	db := s.db.Model(&FsProductSize{}).Where("`id` in (?) and  `status` = ?", ids, 1)
	switch sort {
	case "sort-asc":
		db = db.Order("`sort` ASC")
	case "sort-desc":
		db = db.Order("`sort` DESC")
	}
	if err = db.Find(&resp).Error; err != nil {
		return nil, err
	}
	return
}
func (s *FsProductSizeModel) CountByStatus(ctx context.Context, status int) (total int64, err error) {
	err = s.db.WithContext(ctx).Model(&FsProductSize{}).Where("`status` = ? limit 1", status).Count(&total).Error
	if err != nil {
		return 0, err
	}
	return
}
func (s *FsProductSizeModel) GetAllByProductIds(ctx context.Context, productIds []int64, sort string) (resp []FsProductSize, err error) {
	db := s.db.WithContext(ctx).Model(&FsProductSize{}).Where("`product_id` in(?) and  `status` = ?", productIds, 1)
	switch sort {
	case "sort-asc":
		db = db.Order("`sort` ASC")
	case "sort-desc":
		db = db.Order("`sort` DESC")
	}
	err = db.Find(&resp).Error
	if err != nil {
		return nil, err
	}
	return
}
